import{s as pl,n as fl,o as hl}from"../chunks/scheduler.7bc62968.js";import{S as ml,i as ul,g as r,s as n,r as p,A as dl,h as o,f as l,c as a,j as ol,u as f,x as s,k as sl,y as cl,a as i,v as h,d as m,t as u,w as d}from"../chunks/index.66556066.js";import{Y as bt}from"../chunks/Youtube.0c12a780.js";import{C as gl}from"../chunks/CodeBlock.a759539a.js";import{H as c}from"../chunks/Heading.3f0870db.js";function wl($t){let g,ve,ge,ye,w,be,v,xt=`When creating computer-generated images to use as synthetic training data, ideally we want the images to look as realistic as possible.
Physically Based Renderers (PBR) such as <a href="https://www.blender.org" rel="nofollow">Blender Cycles</a>
or <a href="https://unity.com" rel="nofollow">Unity</a> help to create images that are super realistic and look and feel just like they do in the real world.`,$e,y,Pt=`Imagine you’re creating an image of a shiny apple. Now, when you color that apple, you want it to look realistic, right?
That’s where something called PBR comes in.`,xe,b,Tt='<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/apple.jpg" alt="apple"/>',Pe,$,Lt="Okay, let’s break it down:",Te,x,Ct="<em>Colors and Light:</em>",Le,P,Mt=`<li>When light shines on objects, it interacts with them in different ways. PBR tries to figure out and simulate this interaction.</li> <li>Think about how light hits the apple. Some parts may be brighter where the light directly hits, and some parts might be darker
where the light is blocked or doesn’t reach as much.</li>`,Ce,T,_t="<em>Materials:</em>",Me,L,Bt="<li>Different materials react to light differently. For example, a shiny metallic surface reflects light more than a soft, matte fabric.</li> <li>PBR takes into account the material of an object, so if you’re rendering a metal vase, it will reflect light differently than a fluffy teddy bear.</li>",_e,C,Ht="<em>Textures:</em>",Be,M,kt="<li>PBR uses textures to add details like bumps, scratches, or tiny grooves on the surface of objects. This makes things look more real because, in the real world, very few things are perfectly smooth.</li>",He,_,Rt="<em>Realism:</em>",ke,B,Dt="<li>PBR aims to make things look as close to real life as possible. It does this by considering how light behaves in reality, how different materials interact with light, and how surfaces have small imperfections.</li>",Re,H,jt="<em>Layers of Light:</em>",De,k,Ut="<li>Imagine you’re looking at a glass of water. PBR will try to simulate the way light passes through the water and how it might distort what you see.</li> <li>It considers how multiple layers of how light interact with different parts of an object, making the rendered image more realistic.</li>",je,R,It=`PBR also simplifies the workflow. Instead of manually tweaking many parameters to get the right look,
you can use a set of standardized materials and lighting models.
This makes the process more intuitive and user-friendly.`,Ue,D,St=`Now, think about training AI models like those used in computer vision.
If you’re teaching a computer to recognize objects in images, it’s beneficial to have a diverse set of
images that closely mimic real-world scenarios. PBR helps in generating synthetic data that looks so real that it can be used
to train computer vision models effectively.`,Ie,j,Gt=`There are several 3D rendering engines that you can use for PBR, including <a href="https://www.blender.org" rel="nofollow">Blender Cycles</a>
or <a href="https://unity.com" rel="nofollow">Unity</a>. We are going to focus on Blender because it is open source and there are a lot of resources about Blender.`,Se,U,Ge,I,At=`Blender is a powerful, open-source 3D computer graphics software used for creating animated films, visual effects, art, 3D games, and more.
It encompasses a wide range of features, making it a versatile tool for artists, animators, and developers.
Let’s start off by walking through a basic example of rendering a synthetic image of an elephant.`,Ae,S,zt="Here are the essential steps:",ze,G,qt=`<li>Create the elephant model. The one shown below was created with the <a href="https://metascan.ai" rel="nofollow">Metascan</a> app using Photogrammetry.
Photogrammetry is a way of turning regular photos into a 3D model. It’s like taking a bunch of pictures of your toy from different angles
and then using those pictures to make a computer version of it.</li> <li>Create the background - this was a multi-step process. See <a href="https://github.com/kfahn22/Synthetic-Data-Creation-in-Blender/tree/main/BACKGROUND" rel="nofollow">here</a>
for a more detailed explanation.</li> <li>Adjust the lighting and camera positions.</li> <li>Fix the location and rotation of the elephant so that it fits within the frame (or camera view).</li>`,qe,A,Yt="Here is the elephant image generated in Blender:",Ye,z,Et='<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/synthetic-data-creation-PBR/rendered_elephant.png" alt="elephant image"/>',Ee,q,Ot=`It is not completely photorealistic, but probably close enough to train a model to monitor elephant populations. Of course, to do
that we need to create a large dataset of synthetic elephant images! You can use the Blender python environment
<a href="https://docs.blender.org/api/current/info_advanced_blender_as_bpy.html" rel="nofollow">bpy</a> to render
a large number of images with the location and rotation of the elephant randomized.
You can also use a script to help with segmentation, depth, normal, and pose estimation.`,Oe,Y,Ft="Great! How do we get started?",Fe,E,Nt=`Unfortunately, there is a pretty steep learning curve associated with Blender. None of the steps are too complicated,
but wouldn’t it be nice if we could render the dataset without trying to figure all of this out?
Luckily for us, there is a library called BlenderProc that has all the scripts we need to render realistic synthetic data
and annotations and it is built on top of Blender.`,Ne,O,We,F,Wt=`The BlenderProc pipeline was introduced in <a href="https://arxiv.org/abs/1911.01911" rel="nofollow">BlenderProc</a>, Denninger, et. al. and is a modular pipeline built on top of <a href="https://www.blender.org/" rel="nofollow">Blender</a>.
It can be used to generate images in a variety of use cases, including segmentation, depth, normal and pose estimation.`,Je,N,Jt=`It is specifically created to help in the generation of realistic looking images for the training of convolutional neural networks.<br/>
It has the following properties which make it a great choice for synthetic data generation:`,Qe,W,Qt="<li>Procedural Generation: Enables the automated creation of complex 3D scenes with variations using procedural techniques.</li> <li>Simulation: Supports the integration of simulations, including physics simulations, to enhance realism.</li> <li>Large-Scale Generation: Designed to handle large-scale scene generation efficiently, making it suitable for diverse applications.</li> <li>Automation and Scalability:<ul><li>Scripting: Allows users to automate the generation process by employing python scripts to tailor BlenderProc to their specific needs and configure parameters.</li> <li>Parallel Processing: Supports parallel processing for scalability, making it efficient for generating a large number of scenes.</li></ul></li>",Ze,J,Zt="You can install BlenderProc via pip:",Ke,Q,Xe,Z,Kt='Alternately, you can clone the official <a href="https://github.com/DLR-RM/BlenderProc" rel="nofollow">BlenderProc repository</a> from GitHub using Git:',Ve,K,Xt="<code>git clone https://github.com/DLR-RM/BlenderProc</code>",et,X,Vt="BlenderProc must be run inside the blender python environment (bpy), as this is the only way to access the Blender API.",tt,V,el="<code>blenderproc run &lt;your_python_script&gt;</code>",lt,ee,tl=`You can check out this notebook to try BlenderProc in Google Colab, demos the basic examples provided <a href="https://github.com/DLR-RM/BlenderProc/tree/main/examples/basics" rel="nofollow">here</a>.
Here are some images rendered with the basic example:`,it,te,ll='<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/synthetic-data-creation-PBR/colors.png" alt="colors"/> <img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/synthetic-data-creation-PBR/normals.png" alt="normals"/> <img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/synthetic-data-creation-PBR/depth.png" alt="depth"/>',nt,le,at,ie,il='<li><a href="https://docs.blender.org/manual/en/latest/0" rel="nofollow">User Manual</a></li> <li><a href="https://awesome-blender.netlify.app" rel="nofollow">Awesome-blender — Extensive list of resources</a></li> <li><a href="https://www.youtube.com/@BlenderOfficial" rel="nofollow">Blender Youtube Channel</a></li>',rt,ne,ot,ae,st,re,pt,oe,ft,se,ht,pe,nl='<li><a href="https://iopscience.iop.org/article/10.1088/1361-6501/acc59e/pdf_" rel="nofollow">Developing digital twins of multi-camera metrology systems in Blender</a></li> <li><a href="https://www.saifkhichi.com/blog/blender-depth-map-surface-normals" rel="nofollow">Generate Depth and Normal Maps with Blender</a></li> <li><a href="https://medium.com/rowden/object-detection-with-synthetic-training-data-f6735a5a34bc" rel="nofollow">Object detection with synthetic training data</a></li>',mt,fe,ut,he,al='<li><a href="https://github.com/DLR-RM/BlenderProc" rel="nofollow">BlenderProc Github Repo</a></li> <li><a href="https://elib.dlr.de/139317/1/denninger.pdf" rel="nofollow">BlenderProc: Reducing the Reality Gap with Photorealistic Rendering</a></li> <li><a href="https://dlr-rm.github.io/BlenderProc/" rel="nofollow">Documentation</a></li>',dt,me,ct,ue,gt,de,wt,ce,rl='<li><a href="">3D Menagerie: Modeling the 3D Shape and Pose of Animals</a></li> <li><a href="">Fake It Till You Make It: Face analysis in the wild using synthetic data alone</a></li> <li><a href="https://arxiv.org/pdf/2106.08045.pdf" rel="nofollow">Object Detection and Autoencoder-Based 6D Pose Estimation for Highly Cluttered Bin Picking</a></li> <li><a href="https://arxiv.org/abs/1912.08265" rel="nofollow">Learning from Synthetic Animals</a></li>',vt,we,yt;return w=new c({props:{title:"Using a 3D Renderer to Generate Synthetic Data",local:"using-a-3d-renderer-to-generate-synthetic-data",headingTag:"h1"}}),U=new c({props:{title:"Blender",local:"blender",headingTag:"h2"}}),O=new c({props:{title:"BlenderProc",local:"blenderproc",headingTag:"h2"}}),Q=new gl({props:{code:"JTIwcGlwJTIwaW5zdGFsbCUyMGJsZW5kZXJQcm9j",highlighted:" pip install blenderProc",wrap:!1}}),le=new c({props:{title:"Blender Resources",local:"blender-resources",headingTag:"h2"}}),ne=new c({props:{title:"The following video explains how to render a 3D syntehtic dataset in Blender:",local:"the-following-video-explains-how-to-render-a-3d-syntehtic-dataset-in-blender",headingTag:"h3"}}),ae=new bt({props:{id:"E1Pqpfg5kSo"}}),re=new c({props:{title:"The following video explains how to create a 3D object using Photogrammetry:",local:"the-following-video-explains-how-to-create-a-3d-object-using-photogrammetry",headingTag:"h3"}}),oe=new bt({props:{id:"Pcqokf3PG_4"}}),se=new c({props:{title:"Papers / Blogs",local:"papers--blogs",headingTag:"h2"}}),fe=new c({props:{title:"BlenderProc Resources",local:"blenderproc-resources",headingTag:"h2"}}),me=new c({props:{title:"The following video provides an overview of the BlenderProc pipeline:",local:"the-following-video-provides-an-overview-of-the-blenderproc-pipeline",headingTag:"h3"}}),ue=new bt({props:{id:"1AvY_iS6xQA"}}),de=new c({props:{title:"Papers",local:"papers",headingTag:"h2"}}),{c(){g=r("meta"),ve=n(),ge=r("p"),ye=n(),p(w.$$.fragment),be=n(),v=r("p"),v.innerHTML=xt,$e=n(),y=r("p"),y.textContent=Pt,xe=n(),b=r("p"),b.innerHTML=Tt,Pe=n(),$=r("p"),$.textContent=Lt,Te=n(),x=r("p"),x.innerHTML=Ct,Le=n(),P=r("ul"),P.innerHTML=Mt,Ce=n(),T=r("p"),T.innerHTML=_t,Me=n(),L=r("ul"),L.innerHTML=Bt,_e=n(),C=r("p"),C.innerHTML=Ht,Be=n(),M=r("ul"),M.innerHTML=kt,He=n(),_=r("p"),_.innerHTML=Rt,ke=n(),B=r("ul"),B.innerHTML=Dt,Re=n(),H=r("p"),H.innerHTML=jt,De=n(),k=r("ul"),k.innerHTML=Ut,je=n(),R=r("p"),R.textContent=It,Ue=n(),D=r("p"),D.textContent=St,Ie=n(),j=r("p"),j.innerHTML=Gt,Se=n(),p(U.$$.fragment),Ge=n(),I=r("p"),I.textContent=At,Ae=n(),S=r("p"),S.textContent=zt,ze=n(),G=r("ul"),G.innerHTML=qt,qe=n(),A=r("p"),A.textContent=Yt,Ye=n(),z=r("p"),z.innerHTML=Et,Ee=n(),q=r("p"),q.innerHTML=Ot,Oe=n(),Y=r("p"),Y.textContent=Ft,Fe=n(),E=r("p"),E.textContent=Nt,Ne=n(),p(O.$$.fragment),We=n(),F=r("p"),F.innerHTML=Wt,Je=n(),N=r("p"),N.innerHTML=Jt,Qe=n(),W=r("ul"),W.innerHTML=Qt,Ze=n(),J=r("p"),J.textContent=Zt,Ke=n(),p(Q.$$.fragment),Xe=n(),Z=r("p"),Z.innerHTML=Kt,Ve=n(),K=r("p"),K.innerHTML=Xt,et=n(),X=r("p"),X.textContent=Vt,tt=n(),V=r("p"),V.innerHTML=el,lt=n(),ee=r("p"),ee.innerHTML=tl,it=n(),te=r("p"),te.innerHTML=ll,nt=n(),p(le.$$.fragment),at=n(),ie=r("ul"),ie.innerHTML=il,rt=n(),p(ne.$$.fragment),ot=n(),p(ae.$$.fragment),st=n(),p(re.$$.fragment),pt=n(),p(oe.$$.fragment),ft=n(),p(se.$$.fragment),ht=n(),pe=r("ul"),pe.innerHTML=nl,mt=n(),p(fe.$$.fragment),ut=n(),he=r("ul"),he.innerHTML=al,dt=n(),p(me.$$.fragment),ct=n(),p(ue.$$.fragment),gt=n(),p(de.$$.fragment),wt=n(),ce=r("ul"),ce.innerHTML=rl,vt=n(),we=r("p"),this.h()},l(e){const t=dl("svelte-u9bgzb",document.head);g=o(t,"META",{name:!0,content:!0}),t.forEach(l),ve=a(e),ge=o(e,"P",{}),ol(ge).forEach(l),ye=a(e),f(w.$$.fragment,e),be=a(e),v=o(e,"P",{"data-svelte-h":!0}),s(v)!=="svelte-m7n1rz"&&(v.innerHTML=xt),$e=a(e),y=o(e,"P",{"data-svelte-h":!0}),s(y)!=="svelte-8dopem"&&(y.textContent=Pt),xe=a(e),b=o(e,"P",{"data-svelte-h":!0}),s(b)!=="svelte-1xedqaw"&&(b.innerHTML=Tt),Pe=a(e),$=o(e,"P",{"data-svelte-h":!0}),s($)!=="svelte-rwpo57"&&($.textContent=Lt),Te=a(e),x=o(e,"P",{"data-svelte-h":!0}),s(x)!=="svelte-a1wtw0"&&(x.innerHTML=Ct),Le=a(e),P=o(e,"UL",{"data-svelte-h":!0}),s(P)!=="svelte-13t94ri"&&(P.innerHTML=Mt),Ce=a(e),T=o(e,"P",{"data-svelte-h":!0}),s(T)!=="svelte-12ga40z"&&(T.innerHTML=_t),Me=a(e),L=o(e,"UL",{"data-svelte-h":!0}),s(L)!=="svelte-jki7je"&&(L.innerHTML=Bt),_e=a(e),C=o(e,"P",{"data-svelte-h":!0}),s(C)!=="svelte-1ps8oir"&&(C.innerHTML=Ht),Be=a(e),M=o(e,"UL",{"data-svelte-h":!0}),s(M)!=="svelte-10292rw"&&(M.innerHTML=kt),He=a(e),_=o(e,"P",{"data-svelte-h":!0}),s(_)!=="svelte-1pfshgm"&&(_.innerHTML=Rt),ke=a(e),B=o(e,"UL",{"data-svelte-h":!0}),s(B)!=="svelte-1xn1kss"&&(B.innerHTML=Dt),Re=a(e),H=o(e,"P",{"data-svelte-h":!0}),s(H)!=="svelte-17qeghi"&&(H.innerHTML=jt),De=a(e),k=o(e,"UL",{"data-svelte-h":!0}),s(k)!=="svelte-us2oy9"&&(k.innerHTML=Ut),je=a(e),R=o(e,"P",{"data-svelte-h":!0}),s(R)!=="svelte-1v41sfn"&&(R.textContent=It),Ue=a(e),D=o(e,"P",{"data-svelte-h":!0}),s(D)!=="svelte-jdzbq9"&&(D.textContent=St),Ie=a(e),j=o(e,"P",{"data-svelte-h":!0}),s(j)!=="svelte-11n56g1"&&(j.innerHTML=Gt),Se=a(e),f(U.$$.fragment,e),Ge=a(e),I=o(e,"P",{"data-svelte-h":!0}),s(I)!=="svelte-1ja2qyi"&&(I.textContent=At),Ae=a(e),S=o(e,"P",{"data-svelte-h":!0}),s(S)!=="svelte-h0dm8y"&&(S.textContent=zt),ze=a(e),G=o(e,"UL",{"data-svelte-h":!0}),s(G)!=="svelte-1wmb2f5"&&(G.innerHTML=qt),qe=a(e),A=o(e,"P",{"data-svelte-h":!0}),s(A)!=="svelte-cunkwf"&&(A.textContent=Yt),Ye=a(e),z=o(e,"P",{"data-svelte-h":!0}),s(z)!=="svelte-1gh6diz"&&(z.innerHTML=Et),Ee=a(e),q=o(e,"P",{"data-svelte-h":!0}),s(q)!=="svelte-1rcar4r"&&(q.innerHTML=Ot),Oe=a(e),Y=o(e,"P",{"data-svelte-h":!0}),s(Y)!=="svelte-1m3a08l"&&(Y.textContent=Ft),Fe=a(e),E=o(e,"P",{"data-svelte-h":!0}),s(E)!=="svelte-gbqbu7"&&(E.textContent=Nt),Ne=a(e),f(O.$$.fragment,e),We=a(e),F=o(e,"P",{"data-svelte-h":!0}),s(F)!=="svelte-r6gkd"&&(F.innerHTML=Wt),Je=a(e),N=o(e,"P",{"data-svelte-h":!0}),s(N)!=="svelte-16hmwa"&&(N.innerHTML=Jt),Qe=a(e),W=o(e,"UL",{"data-svelte-h":!0}),s(W)!=="svelte-17nrqt5"&&(W.innerHTML=Qt),Ze=a(e),J=o(e,"P",{"data-svelte-h":!0}),s(J)!=="svelte-1djvpst"&&(J.textContent=Zt),Ke=a(e),f(Q.$$.fragment,e),Xe=a(e),Z=o(e,"P",{"data-svelte-h":!0}),s(Z)!=="svelte-e1u0g4"&&(Z.innerHTML=Kt),Ve=a(e),K=o(e,"P",{"data-svelte-h":!0}),s(K)!=="svelte-bk79vf"&&(K.innerHTML=Xt),et=a(e),X=o(e,"P",{"data-svelte-h":!0}),s(X)!=="svelte-1xel87t"&&(X.textContent=Vt),tt=a(e),V=o(e,"P",{"data-svelte-h":!0}),s(V)!=="svelte-1kbhx2z"&&(V.innerHTML=el),lt=a(e),ee=o(e,"P",{"data-svelte-h":!0}),s(ee)!=="svelte-1jtbgar"&&(ee.innerHTML=tl),it=a(e),te=o(e,"P",{"data-svelte-h":!0}),s(te)!=="svelte-1xh04a8"&&(te.innerHTML=ll),nt=a(e),f(le.$$.fragment,e),at=a(e),ie=o(e,"UL",{"data-svelte-h":!0}),s(ie)!=="svelte-1hlup7b"&&(ie.innerHTML=il),rt=a(e),f(ne.$$.fragment,e),ot=a(e),f(ae.$$.fragment,e),st=a(e),f(re.$$.fragment,e),pt=a(e),f(oe.$$.fragment,e),ft=a(e),f(se.$$.fragment,e),ht=a(e),pe=o(e,"UL",{"data-svelte-h":!0}),s(pe)!=="svelte-1dizrlz"&&(pe.innerHTML=nl),mt=a(e),f(fe.$$.fragment,e),ut=a(e),he=o(e,"UL",{"data-svelte-h":!0}),s(he)!=="svelte-1na588e"&&(he.innerHTML=al),dt=a(e),f(me.$$.fragment,e),ct=a(e),f(ue.$$.fragment,e),gt=a(e),f(de.$$.fragment,e),wt=a(e),ce=o(e,"UL",{"data-svelte-h":!0}),s(ce)!=="svelte-df5x24"&&(ce.innerHTML=rl),vt=a(e),we=o(e,"P",{}),ol(we).forEach(l),this.h()},h(){sl(g,"name","hf:doc:metadata"),sl(g,"content",vl)},m(e,t){cl(document.head,g),i(e,ve,t),i(e,ge,t),i(e,ye,t),h(w,e,t),i(e,be,t),i(e,v,t),i(e,$e,t),i(e,y,t),i(e,xe,t),i(e,b,t),i(e,Pe,t),i(e,$,t),i(e,Te,t),i(e,x,t),i(e,Le,t),i(e,P,t),i(e,Ce,t),i(e,T,t),i(e,Me,t),i(e,L,t),i(e,_e,t),i(e,C,t),i(e,Be,t),i(e,M,t),i(e,He,t),i(e,_,t),i(e,ke,t),i(e,B,t),i(e,Re,t),i(e,H,t),i(e,De,t),i(e,k,t),i(e,je,t),i(e,R,t),i(e,Ue,t),i(e,D,t),i(e,Ie,t),i(e,j,t),i(e,Se,t),h(U,e,t),i(e,Ge,t),i(e,I,t),i(e,Ae,t),i(e,S,t),i(e,ze,t),i(e,G,t),i(e,qe,t),i(e,A,t),i(e,Ye,t),i(e,z,t),i(e,Ee,t),i(e,q,t),i(e,Oe,t),i(e,Y,t),i(e,Fe,t),i(e,E,t),i(e,Ne,t),h(O,e,t),i(e,We,t),i(e,F,t),i(e,Je,t),i(e,N,t),i(e,Qe,t),i(e,W,t),i(e,Ze,t),i(e,J,t),i(e,Ke,t),h(Q,e,t),i(e,Xe,t),i(e,Z,t),i(e,Ve,t),i(e,K,t),i(e,et,t),i(e,X,t),i(e,tt,t),i(e,V,t),i(e,lt,t),i(e,ee,t),i(e,it,t),i(e,te,t),i(e,nt,t),h(le,e,t),i(e,at,t),i(e,ie,t),i(e,rt,t),h(ne,e,t),i(e,ot,t),h(ae,e,t),i(e,st,t),h(re,e,t),i(e,pt,t),h(oe,e,t),i(e,ft,t),h(se,e,t),i(e,ht,t),i(e,pe,t),i(e,mt,t),h(fe,e,t),i(e,ut,t),i(e,he,t),i(e,dt,t),h(me,e,t),i(e,ct,t),h(ue,e,t),i(e,gt,t),h(de,e,t),i(e,wt,t),i(e,ce,t),i(e,vt,t),i(e,we,t),yt=!0},p:fl,i(e){yt||(m(w.$$.fragment,e),m(U.$$.fragment,e),m(O.$$.fragment,e),m(Q.$$.fragment,e),m(le.$$.fragment,e),m(ne.$$.fragment,e),m(ae.$$.fragment,e),m(re.$$.fragment,e),m(oe.$$.fragment,e),m(se.$$.fragment,e),m(fe.$$.fragment,e),m(me.$$.fragment,e),m(ue.$$.fragment,e),m(de.$$.fragment,e),yt=!0)},o(e){u(w.$$.fragment,e),u(U.$$.fragment,e),u(O.$$.fragment,e),u(Q.$$.fragment,e),u(le.$$.fragment,e),u(ne.$$.fragment,e),u(ae.$$.fragment,e),u(re.$$.fragment,e),u(oe.$$.fragment,e),u(se.$$.fragment,e),u(fe.$$.fragment,e),u(me.$$.fragment,e),u(ue.$$.fragment,e),u(de.$$.fragment,e),yt=!1},d(e){e&&(l(ve),l(ge),l(ye),l(be),l(v),l($e),l(y),l(xe),l(b),l(Pe),l($),l(Te),l(x),l(Le),l(P),l(Ce),l(T),l(Me),l(L),l(_e),l(C),l(Be),l(M),l(He),l(_),l(ke),l(B),l(Re),l(H),l(De),l(k),l(je),l(R),l(Ue),l(D),l(Ie),l(j),l(Se),l(Ge),l(I),l(Ae),l(S),l(ze),l(G),l(qe),l(A),l(Ye),l(z),l(Ee),l(q),l(Oe),l(Y),l(Fe),l(E),l(Ne),l(We),l(F),l(Je),l(N),l(Qe),l(W),l(Ze),l(J),l(Ke),l(Xe),l(Z),l(Ve),l(K),l(et),l(X),l(tt),l(V),l(lt),l(ee),l(it),l(te),l(nt),l(at),l(ie),l(rt),l(ot),l(st),l(pt),l(ft),l(ht),l(pe),l(mt),l(ut),l(he),l(dt),l(ct),l(gt),l(wt),l(ce),l(vt),l(we)),l(g),d(w,e),d(U,e),d(O,e),d(Q,e),d(le,e),d(ne,e),d(ae,e),d(re,e),d(oe,e),d(se,e),d(fe,e),d(me,e),d(ue,e),d(de,e)}}}const vl='{"title":"Using a 3D Renderer to Generate Synthetic Data","local":"using-a-3d-renderer-to-generate-synthetic-data","sections":[{"title":"Blender","local":"blender","sections":[],"depth":2},{"title":"BlenderProc","local":"blenderproc","sections":[],"depth":2},{"title":"Blender Resources","local":"blender-resources","sections":[{"title":"The following video explains how to render a 3D syntehtic dataset in Blender:","local":"the-following-video-explains-how-to-render-a-3d-syntehtic-dataset-in-blender","sections":[],"depth":3},{"title":"The following video explains how to create a 3D object using Photogrammetry:","local":"the-following-video-explains-how-to-create-a-3d-object-using-photogrammetry","sections":[],"depth":3}],"depth":2},{"title":"Papers / Blogs","local":"papers--blogs","sections":[],"depth":2},{"title":"BlenderProc Resources","local":"blenderproc-resources","sections":[{"title":"The following video provides an overview of the BlenderProc pipeline:","local":"the-following-video-provides-an-overview-of-the-blenderproc-pipeline","sections":[],"depth":3}],"depth":2},{"title":"Papers","local":"papers","sections":[],"depth":2}],"depth":1}';function yl($t){return hl(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class Ll extends ml{constructor(g){super(),ul(this,g,yl,wl,pl,{})}}export{Ll as component};
